==> simple_popup_blocks-8.x-1.0.tar.gz: simple_popup_blocks/src/Controller/SimplePopupBlocksController.php <==
<?php

namespace Drupal\simple_popup_blocks\Controller;

use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Core\Controller\ControllerBase;
use Drupal\simple_popup_blocks\SimplePopupBlocksStorage;

/**
 * Controller routines for manage page routes.
 */
class SimplePopupBlocksController extends ControllerBase {

  /**
   * Manage page controller method to list the data.
   */
  public function manage() {
    $header = [
      ['data' => $this->t('S.No')],
      ['data' => $this->t('Popup selector')],
      ['data' => $this->t('Popup sourse')],
      ['data' => $this->t('Layout')],
      ['data' => $this->t('Triggering')],
      ['data' => $this->t('Status')],
      ['data' => $this->t('Edit')],
      ['data' => $this->t('Delete')],
    ];

    $result = SimplePopupBlocksStorage::loadAll();

    $rows = [];
    $increment = 1;
    foreach ($result as $row) {
      $popup_src = $row->type == 1 ? 'Custom css' : 'Drupal blocks';
      $url = Url::fromRoute('simple_popup_blocks.edit', ['first' => $row->pid]);
      $edit = Link::fromTextAndUrl($this->t('Edit'), $url);
      $edit = $edit->toRenderable();

      $url = Url::fromRoute('simple_popup_blocks.delete', ['first' => $row->pid]);
      $delete = Link::fromTextAndUrl($this->t('Delete'), $url);
      $delete = $delete->toRenderable();

      $layouts = [
        0 => $this
          ->t('Top left'),
        1 => $this
          ->t('Top Right'),
        2 => $this
          ->t('Bottom left'),
        3 => $this
          ->t('Bottom Right'),
        4 => $this
          ->t('Center'),
        5 => $this
          ->t('Top center'),
        6 => $this
          ->t('Top bar'),
        7 => $this
          ->t('Bottom bar'),
        8 => $this
          ->t('Left bar'),
        9 => $this
          ->t('Right bar'),
      ];
      $layout = $layouts[$row->layout];
      $status = $row->status ? 'Active' : 'Inactive';
      $status = $row->status ? 'Active' : 'Inactive';
      $trigger_method = $row->trigger_method ? 'Manual' : 'Automatic';

      $rows[] = [
        ['data' => $increment],
        ['data' => $row->identifier],
        ['data' => $popup_src],
        ['data' => $layout],
        ['data' => $trigger_method],
        ['data' => $status],
        ['data' => $edit],
        ['data' => $delete],
      ];
      $increment++;
    }
    $build['table'] = [
      '#theme' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#empty' => 'No popup settings available.',

    ];

    return $build;
  }

  /**
   * Delete page controller.
   */
  public function delete($first) {
    $result = SimplePopupBlocksStorage::delete($first);
    if ($result) {
      drupal_set_message($this->t('Successfully deleted the popup settings.'));
    }
    return $this->redirect('simple_popup_blocks.manage');
  }

}

==> simple_popup_blocks-8.x-1.2.tar.gz: simple_popup_blocks/src/Controller/SimplePopupBlocksController.php <==
<?php

namespace Drupal\simple_popup_blocks\Controller;

use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Core\Controller\ControllerBase;
use Drupal\simple_popup_blocks\SimplePopupBlocksStorage;

/**
 * Controller routines for manage page routes.
 */
class SimplePopupBlocksController extends ControllerBase {

  /**
   * Manage page controller method to list the data.
   */
  public function manage() {
    $header = [
      ['data' => $this->t('S.No')],
      ['data' => $this->t('Popup selector')],
      ['data' => $this->t('Popup sourse')],
      ['data' => $this->t('Layout')],
      ['data' => $this->t('Triggering')],
      ['data' => $this->t('Status')],
      ['data' => $this->t('Edit')],
      ['data' => $this->t('Delete')],
    ];

    $result = SimplePopupBlocksStorage::loadAll();

    $rows = [];
    $increment = 1;
    foreach ($result as $row) {
      $popup_src = $row->type == 1 ? 'Custom css' : 'Drupal blocks';
      $url = Url::fromRoute('simple_popup_blocks.edit', ['first' => $row->pid]);
      $edit = Link::fromTextAndUrl($this->t('Edit'), $url);
      $edit = $edit->toRenderable();

      $url = Url::fromRoute('simple_popup_blocks.delete', ['first' => $row->pid]);
      $delete = Link::fromTextAndUrl($this->t('Delete'), $url);
      $delete = $delete->toRenderable();

      $layouts = [
        0 => $this
          ->t('Top left'),
        1 => $this
          ->t('Top Right'),
        2 => $this
          ->t('Bottom left'),
        3 => $this
          ->t('Bottom Right'),
        4 => $this
          ->t('Center'),
        5 => $this
          ->t('Top center'),
        6 => $this
          ->t('Top bar'),
        7 => $this
          ->t('Bottom bar'),
        8 => $this
          ->t('Left bar'),
        9 => $this
          ->t('Right bar'),
      ];
      $layout = $layouts[$row->layout];
      $status = $row->status ? 'Active' : 'Inactive';
      switch ($row->trigger_method) {
        case '0':
          $trigger_method = 'Automatic';
          break;

        case '1':
          $trigger_method = 'Manual';
          break;

        case '2':
          $trigger_method = 'Browser/tab close';
          break;
      }
      $rows[] = [
        ['data' => $increment],
        ['data' => $row->identifier],
        ['data' => $popup_src],
        ['data' => $layout],
        ['data' => $trigger_method],
        ['data' => $status],
        ['data' => $edit],
        ['data' => $delete],
      ];
      $increment++;
    }
    $build['table'] = [
      '#theme' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#empty' => 'No popup settings available.',

    ];

    return $build;
  }

  /**
   * Delete page controller.
   */
  public function delete($first) {
    $result = SimplePopupBlocksStorage::delete($first);
    if ($result) {
      drupal_set_message($this->t('Successfully deleted the popup settings.'));
    }
    return $this->redirect('simple_popup_blocks.manage');
  }

}
